pub fn load(durable: &Durable, target: &str) -> Option<CachedCred>Expand description
Load the cached credential for target, if present and parseable.
pub fn load(durable: &Durable, target: &str) -> Option<CachedCred>Load the cached credential for target, if present and parseable.