pub fn load_file(dir: &Path, target: &str) -> Option<CachedCred>Expand description
Load a credential from the file cache, if present and parseable.
pub fn load_file(dir: &Path, target: &str) -> Option<CachedCred>Load a credential from the file cache, if present and parseable.