pub fn read_document(path: &str) -> Result<(Value, Format), String>
Read + parse a config file from a local path into its document, deciding the format from the extension (else by sniffing the text). Errors name the path.