pub enum Impl {
BuiltIn,
MappingOnly,
Mapped(Mapping),
Code,
Mcp {
server: String,
tool: String,
},
Workflow {
workflow: String,
sync: bool,
},
}Expand description
How a tool is implemented.
Variants
BuiltIn
A built-in executed by the runtime.
MappingOnly
A contract with no implementation until an override maps it.
Mapped(Mapping)
An internal contract implemented by a mapped MCP tool.
Code
A tool registered from Rust by an embedding application.
Mcp
An MCP server tool.
Workflow
A workflow, started by name.