McpCaller

Trait McpCaller 

pub trait McpCaller {
    // Required method
    fn call(
        &self,
        server: &str,
        tool: &str,
        args: Value,
        meta: Value,
        timeout: Duration,
    ) -> Result<(Value, bool), String>;
}
How MCP tools are reached from the turn.

Required Methods

fn call( &self, server: &str, tool: &str, args: Value, meta: Value, timeout: Duration, ) -> Result<(Value, bool), String>

Call tool on server with args and extra _meta; (content, is_error) where content is the structured result when the server gave one.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors